@@ -5,6 +5,6 @@ testthat::test_that("throw the HandTill2001 exception", {
   testthat::expect_error(
     HandTill2001:::throw(string),
     regexp = error_message,
-    class = c("error", "HandTill2001", "condition")
+    class = c("HandTill2001")
   )
 })
